
#ifndef _CH375DLL_H
#define _CH375DLL_H
//#include <stdint.h>
/* Functions from the ch375dll.dll 

   used to control ch375w64.sys. There are all kind of wrapper functions regarding
   USB in this DLL. For the ch55x bootloader there are just 5 functions used. The 
   DLL can handle up to 10 different devices using DeviceIndex for accessing a specific
   one. Ususally just one device is connected meaning DeviceIndex is 0.

   Overview  of the functions:  
   - CH375OpenDevice()  // open a device
   - CH375CloseDevice() // release that device
   - CH375GetUsbID()    // return VID / PID   
   - CH375WriteEndP()   // write to a specific (bulk) endpoint 
   - CH375ReadEndP()    // read from a specific (bulk) endpoint

   Example for creating a import lib (BORLAND tools)
   1. impdef ch375dll.def ch375dll.dll   // reads the DLL exported functions
   2. implib ch375dll.lib ch375dll.def   // create the lib to be linked with the app

*/

#ifdef __cplusplus
  extern "C" {
#endif
/** Open a device

    Opens a specified device. If WhichIndex is set to -1 it scans for a device
    The device remains opened after that operation.
    \param [in] WhichIndex 0..9 or -1
    \return     DevIndex or -1 
*/
int   __stdcall CH375OpenDevice  (int WhichIdx);

/** Close the device
    \param [in] DevIdx 0..9 
    \return     true on success otherwise false 
*/
int  __stdcall CH375CloseDevice (int DevIdx);

/** Read the Ids

    return Vendor ID and Product ID of a given device. Use this function on
    a closed device. If used on a open device its closed after the call.
    \param [in] DevIdx 0..9 
    \return     VID << 16 | PID     
*/
unsigned int __stdcall CH375GetUsbID    (int DevIdx);

/** Read data from an endpoint

    Read a specific in endpoint and return the data in Buf. Len is set to max data
    to read on entry and returns number of valid data on return.
    \param [in]     DevIdx 0..9 
    \param [in]     Epnum  Endpointnumber 1..8 for the bootloader always 2
    \param [out]    Buf    ptr to a buffer retrieving the data
    \param [in,out] Len    ptr to size of buffer, on exit contains number of valid data  
    \return         true on success otherwise false 
*/
int  __stdcall CH375ReadEndP    (int DevIdx, int Epnum, char *Buf, unsigned int *Len);

/** Write data to an endpoint
    
    Write the buffer contents to a specific endpoint. 
    \param [in]     DevIdx 0..9 
    \param [in]     Epnum  Endpointnumber 1..8 for the bootloader always 2
    \param [in]     Buf    ptr to a buffer send to the endpoint
    \param [in,out] Len    ptr to size of buffer, on exit contains number of data written  
    \return         true on success otherwise false 
*/
int  __stdcall CH375WriteEndP   (int DevIdx, int Epnum, char *Buf, unsigned int *Len);

#ifdef __cplusplus
  }
#endif

#endif
